import React, { useState, useEffect } from 'react';

const BasicDetailsStep = ({
  intent,
  setIntent,
  role,
  setRole,
  propertyType,
  setPropertyType,
  sizeUnit,
  setSizeUnit,
  size,
  setSize,
  length,
  setLength,
  breadth,
  setBreadth,
}) => {
  const [showFlash, setShowFlash] = useState(false);

  // Add default role as Landowner
  useEffect(() => {
    if (!role) {
      setRole('Landowner');
    }
  }, []);

  const handleLeaseClick = () => {
    setShowFlash(true);
    setTimeout(() => setShowFlash(false), 3000);
    setIntent('Lease');
  };

  // Standard fields for Landowner and Agent
  const StandardFields = () => (
    <>
      <div className="flex flex-col w-full">
        <p className="mb-4 text-base sm:text-lg">Post property for?</p>
        <div className="flex flex-wrap gap-4">
          <button
            onClick={() => setIntent('Sell')}
            className={`rounded-full px-4 py-2 sm:px-6 ${
              intent === 'Sell'
                ? 'bg-purple-600 text-white'
                : 'border border-gray-300 text-gray-700'
            } transition-colors duration-200`}
          >
            Sell
          </button>
          <button
            onClick={handleLeaseClick}
            className={`rounded-full px-4 py-2 sm:px-6 ${
              intent === 'Lease'
                ? 'bg-purple-600 text-white'
                : 'border border-gray-300 text-gray-700'
            } transition-colors duration-200`}
          >
            Lease
          </button>
        </div>
      </div>

      <div className="mt-6 sm:mt-8 w-full">
        <h3 className="mb-3 text-base font-medium sm:mb-4 sm:text-lg">
          Type of Property & Size
        </h3>
        <div className="grid gap-3 sm:gap-4 md:grid-cols-3">
          <select
            className="w-full rounded-lg border border-gray-300 bg-transparent px-3 py-2 text-sm focus:border-purple-600 focus:outline-none sm:px-4 sm:py-2.5"
            value={propertyType}
            onChange={(e) => setPropertyType(e.target.value)}
          >
            <option value="">Select Property Type</option>
            <option value="residential">Residential land</option>
            <option value="commercial">Commercial land</option>
            <option value="agricultural">Agricultural land</option>
          </select>
          <input
            type="text"
            placeholder="Size" 
            value={size}
            onChange={(e) => setSize(e.target.value)}
            className="w-full rounded-lg border border-gray-300 bg-transparent px-3 py-2 text-sm focus:border-purple-600 focus:outline-none sm:px-4 sm:py-2.5"
          />
          <select
            className="w-full rounded-lg border border-gray-300 bg-transparent px-3 py-2 text-sm focus:border-purple-600 focus:outline-none sm:px-4 sm:py-2.5"
            value={sizeUnit}
            onChange={(e) => setSizeUnit(e.target.value)}
          >
            <option value="SQ Yard">SQ Yard</option>
            <option value="SQ Feet">SQ Feet</option>
            <option value="SQ Meter">SQ Meter</option>
          </select>
        </div>
      </div>

      <div className="mt-6 sm:mt-8 w-full">
        <h3 className="mb-3 text-base font-medium sm:mb-4 sm:text-lg">
          Property Dimension
        </h3>
        <div className="grid gap-3 sm:gap-4 md:grid-cols-3">
          <div>
            <label htmlFor="length" className="block text-sm mb-1">Length</label>
            <input
              id="length"
              type="number"
              placeholder="Length"
              value={length}
              onChange={(e) => setLength(e.target.value)}
              className="w-full rounded-lg border border-gray-300 bg-transparent px-3 py-2 text-sm focus:border-purple-600 focus:outline-none sm:px-4 sm:py-2.5"
            />
          </div>
          <div>
            <label htmlFor="breadth" className="block text-sm mb-1">Breadth</label>
            <input
              id="breadth"
              type="number"
              placeholder="Breadth"
              value={breadth}
              onChange={(e) => setBreadth(e.target.value)}
              className="w-full rounded-lg border border-gray-300 bg-transparent px-3 py-2 text-sm focus:border-purple-600 focus:outline-none sm:px-4 sm:py-2.5"
            />
          </div>
        </div>
      </div>
    </>
  );

  return (
    <>
      {showFlash && (
        <div className="fixed top-4 left-1/2 transform -translate-x-1/2 z-50 animate-fade-in-down">
          <div className="bg-yellow-100 border-l-4 border-yellow-500 text-yellow-700 p-4 rounded shadow-lg">
            <p className="text-sm sm:text-base">
              This section is under construction
            </p>
          </div>
        </div>
      )}

      <div className="flex w-full">
        {/* Main content */}
        <div className="flex-1">
          {role !== 'Developer' && <StandardFields />}
        </div>

        {/* Role selection moved to right side */}
        <div className="ml-8 w-64 flex-shrink-0">
          <div className="sticky top-4">
            <p className="mb-4 text-base sm:text-lg">Choose Your Role</p>
            <div className="flex flex-col space-y-3">
              {['Landowner', 'Agent', 'Developer'].map((roleOption) => (
                <button
                  key={roleOption}
                  onClick={() => setRole(roleOption)}
                  className={`w-full rounded-full px-4 py-2 sm:px-6 ${
                    role === roleOption
                      ? 'bg-purple-600 text-white'
                      : 'border border-gray-300 text-gray-700'
                  } transition-colors duration-200`}
                >
                  {roleOption}
                </button>
              ))}
            </div>
          </div>
        </div>
      </div>

      <style jsx>{`
        @keyframes fadeInDown {
          from {
            opacity: 0;
            transform: translate(-50%, -100%);
          }
          to {
            opacity: 1;
            transform: translate(-50%, 0);
          }
        }
        .animate-fade-in-down {
          animation: fadeInDown 0.5s ease-out;
        }
      `}</style>
    </>
  );
};

export default BasicDetailsStep;